' *********************************************************************
'
' Name        : LogErrorToDBUsingADO.vbs
' Author      : 3Ds (UK) Limited
' Description : Example VBScript that can be used to insert an alert 
'               generated by a Sentry-go Quick Monitor using ADO. 
'
'
' Arguments   : #1 - String containing the ODBC DSN we should use.
'
' Notes       : Requires Windows Scripting Host (for VBScript), 
'               Microsoft ADO and the given ODBC data source (DSN).
'
'               In most cases, you can log errors directly from Sentry-go 
'               to a file or database via the Configuration Utility's 
'               "Logging" tab.
'
'               This example can be modified to process the error in 
'               a different way - e.g. to interface with an in-house
'               or external 3rd party system.
'
' *********************************************************************

' Enable in-line error handling
On Error Resume Next

' Define local variables
Dim objDatabase      ' Our database reference
Dim strDSN           ' Data source name
Dim strError         ' Error text
Dim strSource        ' Source

' Get command line arguments 
Set objArgs = WScript.Arguments

If objArgs.Count < 1 Then

   ' Insufficient arguments so ignore request

Else

   ' Format the error & source
   strError   = "<$$ERROR>"
   strSource  = "<$$SOURCE>"

   ' Ensure the error text won't blow the buffer. *** TODO: This is 
   ' dependent on the length of the field in the target database. This 
   ' logic assumes a VARCHAR 255 or equivalent. ***
   strError = Left(strError, 254)

   ' Ensure they don't have any characters that would affect the database
   strError  = Replace (strError, "'", "")
   strSource = Replace (strSource, "'", "")
   
   ' Get the DSN
   strDSN = objArgs(0)

   ' Create a link to the database
   Set objDatabase = CreateObject("ADODB.Connection")
   If Err.Number = 0 Then

      ' Connect to it
      objDatabase.Open "ODBC;Driver=MSDASQL;DSN=" & strDSN
      If Err.Number = 0 Then

         ' Insert the error information into the database
         objDatabase.Execute "INSERT INTO Errors (DateTimeOccurred, PCName, Checkname, Sourcename, ErrorText) VALUES (#<$$TIMELOGGED>#, '<$$SERVER>', '<$$TEST>', '" & strSource & "', '" & strError & "')"
         
         ' Close the connection
         objDatabase.Close
      End If

      Set objDatabase = Nothing
   End If
End If
